==> qtools_profiler-2.1.x-dev.tar.gz: qtools_profiler/src/Controller/DrupalPreviewController.php <==
<?php

namespace Drupal\qtools_profiler\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Http\RequestStack;
use Drupal\Core\Session\AccountProxyInterface;
use Drupal\qtools_common\Utility\QToolsDebug;
use Drupal\qtools_profiler\PerformanceService;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Controller for resources preview report.
 */
class DrupalPreviewController extends ControllerBase {

  /**
   * Performance service.
   *
   * @var \Drupal\qtools_profiler\PerformanceService
   */
  protected $performanceService;

  /**
   * Module handler.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected $moduleHandler;

  /**
   * Drupal\Core\Session\AccountProxy.
   *
   * @var \Drupal\Core\Session\AccountProxyInterface
   */
  protected $accountProxy;

  /**
   * Entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Request Stack.
   *
   * @var \Drupal\Core\Http\RequestStack
   */
  protected $requestStack;

  const HOOK_DRUPAL_RESOURCES_PREVIEW_ALTER = 'qtools_profiler_drupal_resources_preview';

  /**
   * {@inheritdoc}
   */
  public function __construct(
    PerformanceService $performanceService,
    ModuleHandlerInterface $moduleHandler,
    AccountProxyInterface $accountProxy,
    EntityTypeManagerInterface $entityTypeManager,
    RequestStack $requestStack,
  ) {
    $this->performanceService = $performanceService;
    $this->moduleHandler = $moduleHandler;
    $this->accountProxy = $accountProxy;
    $this->entityTypeManager = $entityTypeManager;
    $this->requestStack = $requestStack;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('qtools_profiler.performance'),
      $container->get('module_handler'),
      $container->get('current_user'),
      $container->get('entity_type.manager'),
      $container->get('request_stack'),
    );
  }

  /**
   * Returns page content.
   */
  public function previewResources(Request $request, $id): array {
    $record = $this->performanceService->getRequestRecord($id);
    if (empty($record)) {
      return [];
    }

    $session = $this->requestStack->getMasterRequest()->getSession();
    $messages = $session->get('qpm', []);
    foreach ($messages as $key => $message) {
      if ($message[0] == $id) {
        $build[$key] = [
          '#type' => 'inline_template',
          '#template' => '<span style="color: green">{{ title }}</span>{{ content }}<span style="color: green">{{ caller }}</span><br />',
          '#context' => [
            'content' => QToolsDebug::export(QToolsDebug::cloneFormVarDumper($message[1])),
            'title' => $message[2],
            'caller' => $message[3],
          ],
        ];
      }
    }

    $build['record'] = [
      '#type' => 'inline_template',
      '#template' => '<h4>{{ title }}</h4>{{ content }}<br />',
      '#context' => [
        'title' => $this->t('Route key: @route', ['@route' => $record->route]),
        'content' => QToolsDebug::export(QToolsDebug::cloneFormVarDumper($record)),
      ],
    ];

    // Load and print customer info.
    $account = $this->accountProxy->getAccount();
    $export_data = [
      'current_user_account' => [
        $account,
        $this->t('Current user'),
      ],
    ];
    if ($account->isAuthenticated()) {
      $export_data['current_user_entity'] = [
        $this->entityTypeManager->getStorage('user')->load($account->id()),
        $this->t('User entity'),
      ];
    }

    // Allow other modules to add state info without adding additional routes.
    $this->moduleHandler->alter(static::HOOK_DRUPAL_RESOURCES_PREVIEW_ALTER, $export_data);

    foreach ($export_data as $key => $data) {
      $build[$key] = [
        '#type' => 'inline_template',
        '#template' => '<h4>{{ title }}</h4>{{ content }}<br />',
        '#context' => [
          'title' => $data[1],
          'content' => QToolsDebug::export(QToolsDebug::cloneFormVarDumper($data[0])),
        ],
      ];
    }

    return $build;
  }

}

==> qtools_profiler-2.2.x-dev.tar.gz: qtools_profiler/src/Controller/DrupalPreviewController.php <==
<?php

namespace Drupal\qtools_profiler\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Symfony\Component\HttpFoundation\RequestStack;
use Drupal\Core\Session\AccountProxyInterface;
use Drupal\qtools_common\Utility\QToolsDebug;
use Drupal\qtools_profiler\PerformanceService;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Controller for resources preview report.
 */
class DrupalPreviewController extends ControllerBase {

  /**
   * Performance service.
   *
   * @var \Drupal\qtools_profiler\PerformanceService
   */
  protected $performanceService;

  /**
   * Module handler.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected $moduleHandler;

  /**
   * Drupal\Core\Session\AccountProxy.
   *
   * @var \Drupal\Core\Session\AccountProxyInterface
   */
  protected $accountProxy;

  /**
   * Entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Request Stack.
   *
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected $requestStack;

  const HOOK_DRUPAL_RESOURCES_PREVIEW_ALTER = 'qtools_profiler_drupal_resources_preview';

  /**
   * {@inheritdoc}
   */
  public function __construct(
    PerformanceService $performanceService,
    ModuleHandlerInterface $moduleHandler,
    AccountProxyInterface $accountProxy,
    EntityTypeManagerInterface $entityTypeManager,
    RequestStack $requestStack,
  ) {
    $this->performanceService = $performanceService;
    $this->moduleHandler = $moduleHandler;
    $this->accountProxy = $accountProxy;
    $this->entityTypeManager = $entityTypeManager;
    $this->requestStack = $requestStack;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('qtools_profiler.performance'),
      $container->get('module_handler'),
      $container->get('current_user'),
      $container->get('entity_type.manager'),
      $container->get('request_stack'),
    );
  }

  /**
   * Returns page content.
   */
  public function previewResources(Request $request, $id): array {
    $record = $this->performanceService->getRequestRecord($id);
    if (empty($record)) {
      return [];
    }

    $session = $this->requestStack->getMainRequest()->getSession();
    $messages = $session->get('qpm', []);
    foreach ($messages as $key => $message) {
      if ($message[0] == $id) {
        $build[$key] = [
          '#type' => 'inline_template',
          '#template' => '<span style="color: green">{{ title }}</span>{{ content }}<span style="color: green">{{ caller }}</span><br />',
          '#context' => [
            'content' => QToolsDebug::export(QToolsDebug::cloneFormVarDumper($message[1])),
            'title' => $message[2],
            'caller' => $message[3],
          ],
        ];
      }
    }

    $build['record'] = [
      '#type' => 'inline_template',
      '#template' => '<h4>{{ title }}</h4>{{ content }}<br />',
      '#context' => [
        'title' => $this->t('Route key: @route', ['@route' => $record->route]),
        'content' => QToolsDebug::export(QToolsDebug::cloneFormVarDumper($record)),
      ],
    ];

    // Load and print customer info.
    $account = $this->accountProxy->getAccount();
    $export_data = [
      'current_user_account' => [
        $account,
        $this->t('Current user'),
      ],
    ];
    if ($account->isAuthenticated()) {
      $export_data['current_user_entity'] = [
        $this->entityTypeManager->getStorage('user')->load($account->id()),
        $this->t('User entity'),
      ];
    }

    // Allow other modules to add state info without adding additional routes.
    $this->moduleHandler->alter(static::HOOK_DRUPAL_RESOURCES_PREVIEW_ALTER, $export_data);

    foreach ($export_data as $key => $data) {
      $build[$key] = [
        '#type' => 'inline_template',
        '#template' => '<h4>{{ title }}</h4>{{ content }}<br />',
        '#context' => [
          'title' => $data[1],
          'content' => QToolsDebug::export(QToolsDebug::cloneFormVarDumper($data[0])),
        ],
      ];
    }

    return $build;
  }

}
